
-- CONFIGURATION ----------------------------------


local hide_hotkeys = false
local hide_macro_names = false
local show_all_bags = false


-- END OF CONFIG ----------------------------------


local level = UnitLevel("player")




-- ACTIONBARS -------------------------------------
---------------------------------------------------

-- Hide textures
for _, texture in ipairs({

	-- End caps
	MainMenuBarLeftEndCap,
	MainMenuBarRightEndCap,

	-- Pet actionbar
	SlidingActionBarTexture0,
	SlidingActionBarTexture1,

	-- Shapeshift bar
	ShapeshiftBarLeft,
	ShapeshiftBarRight,
	ShapeshiftBarMiddle,

	-- Experience bar
	MainMenuXPBarTextureLeftCap,
	MainMenuXPBarTextureMid,
	MainMenuXPBarTextureRightCap,

	-- Experience bar, max level
	MainMenuMaxLevelBar0,
	MainMenuMaxLevelBar1,
	MainMenuMaxLevelBar2,
	MainMenuMaxLevelBar3,

	-- Reputation bar
	ReputationWatchBarTexture0,
	ReputationWatchBarTexture1,
	ReputationWatchBarTexture2,
	ReputationWatchBarTexture3,

	-- Reputation bar, max level
	ReputationXPBarTexture0,
	ReputationXPBarTexture1,
	ReputationXPBarTexture2,
	ReputationXPBarTexture3,

	-- Experience bar, divs
	MainMenuXPBarDiv1,
	MainMenuXPBarDiv2,
	MainMenuXPBarDiv3,
	MainMenuXPBarDiv4,
	MainMenuXPBarDiv5,
	MainMenuXPBarDiv6,
	MainMenuXPBarDiv7,
	MainMenuXPBarDiv8,
	MainMenuXPBarDiv9,
	MainMenuXPBarDiv10,
	MainMenuXPBarDiv11,
	MainMenuXPBarDiv12,
	MainMenuXPBarDiv13,
	MainMenuXPBarDiv14,
	MainMenuXPBarDiv15,
	MainMenuXPBarDiv16,
	MainMenuXPBarDiv17,
	MainMenuXPBarDiv18,
	MainMenuXPBarDiv19,

	}) do
	texture:SetTexture(nil)
end

-- Hide frames
for _, frame in ipairs({

	-- Boncus action bar
	BonusActionBarFrameTexture1,
	BonusActionBarFrameTexture2,
	BonusActionBarFrameTexture3,
	BonusActionBarFrameTexture4,

	-- Main menu bar
	MainMenuBarTexture0,
	MainMenuBarTexture1,
	MainMenuBarTexture2,
	MainMenuBarTexture3,
	
	-- Exhaustion tick
	ExhaustionTick,

	}) do
	frame:SetAlpha(0)
end


UIPARENT_MANAGED_FRAME_POSITIONS['MultiBarBottomRight'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['MultiBarRight'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['MultiBarLeft'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['ContainerFrame1'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['ContainerFrame2'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['ContainerFrame3'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['ContainerFrame4'] = nil
UIPARENT_MANAGED_FRAME_POSITIONS['ContainerFrame5'] = nil


-- Move "bottom right" actionbar
MultiBarBottomRight:ClearAllPoints()
MultiBarBottomRight:SetPoint("BOTTOM", 250, 4)


-- Move "multibar right" and make it horizontal
for i=1,12 do 
	_G["MultiBarRightButton"..i]:ClearAllPoints()
	_G["MultiBarRightButton"..i]:SetPoint("BOTTOM", MultiBarBottomLeft, "BOTTOM", 230+i*42, 0)
end


-- Move "multibar left" to replace "multibar right"
MultiBarLeft:ClearAllPoints()
MultiBarLeft:SetPoint("RIGHT", UIParent, "RIGHT", 0, -50)


-- Vehicle bar
VehicleMenuBar:SetScale(0.85)
VehicleMenuBarArtFrame:Hide()


-- Move main actionbar paging buttons
ActionBarUpButton:SetPoint("LEFT", -22, 5)
ActionBarDownButton:SetPoint("LEFT", -22, -14)
MainMenuBarPageNumber:SetPoint("TOP", ActionBarUpButton, "TOP", 0, 8)
ActionBarDownButton:SetParent(ActionBarUpButton)	-- For mouseover
MainMenuBarPageNumber:SetParent(ActionBarUpButton)	-- For mouseover


-- Move XP and reputation bars
local xpBarsFix, noop = CreateFrame("Frame"), function() end
xpBarsFix:SetScript("OnEvent", function(xpBarsFix, event, addon)
	if level == 85 then
		ReputationWatchBar:SetParent(MainMenuBar)
		ReputationWatchBar:SetPoint("TOPLEFT", MainMenuBar, "TOPLEFT", 6, 3)
		ReputationWatchBar.SetPoint = function() end
		ReputationWatchBar:SetScale(0.982)
	else
		MainMenuExpBar:SetParent(MainMenuBar)
		MainMenuExpBar:SetPoint("TOPLEFT", MainMenuBar, "TOPLEFT", 6, 2)
		MainMenuExpBar:SetWidth(1005)
		ReputationWatchBar:SetParent(MainMenuBar)
		ReputationWatchBar:SetPoint("TOPLEFT", MainMenuBar, "TOPLEFT", 6, 10)
		ReputationWatchBar.SetPoint = function() end
		ReputationWatchBar:SetScale(0.982)
	end
end)
xpBarsFix:RegisterEvent("PLAYER_ENTERING_WORLD")
xpBarsFix:RegisterEvent("PLAYER_LEVEL_UP")
xpBarsFix:RegisterEvent("PLAYER_XP_UPDATE")
xpBarsFix:RegisterEvent("PLAYER_TALENT_UPDATE")


-- Create holder frame to prevent glitchy mouseover
local fixShapeshift = CreateFrame("Frame", "ShapeshiftBarHolder", UIParent)
fixShapeshift:SetWidth(235)
fixShapeshift:SetHeight(45)
fixShapeshift:SetPoint("BOTTOMLEFT", ShapeshiftBarFrame, "BOTTOMLEFT", 0, -3)
fixShapeshift:SetFrameStrata(LOW)	-- Stop interfering with pet actionbar
ShapeshiftBarFrame:SetFrameStrata(BACKGROUND)	-- Stop interfering with the new shapeshift frame
for i=1,6 do
	_G["ShapeshiftButton"..i]:SetParent(fixShapeshift)
end


-- Fix for Blizzards disappearing action button textures >_>
hooksecurefunc("ActionButton_ShowGrid", function(btn)
	local buttonTexture = _G[btn:GetName().."NormalTexture"]:SetVertexColor(1, 1, 1, 1)
end)


-- Hide hotkeys (Credit: Nightcracker)
if hide_hotkeys then
	local noop = function() end
	hooksecurefunc("ActionButton_Update", function(btn)
		local hotkey = _G[btn:GetName().."HotKey"]
		hotkey:SetText("")
		hotkey.Show = noop
		hotkey:Hide()
	end)
end


-- Hide macro text on buttons
if hide_macro_names then
	hooksecurefunc("ActionButton_Update", function(btn)
		local name = _G[btn:GetName().."Name"]
		name:Hide()
	end)
end




-- BAGS -------------------------------------------
---------------------------------------------------

-- Create holder frame to prevent glitchy mouseover
local BagHolder = CreateFrame("Frame", "BagHolder", UIParent)
BagHolder:SetHeight(35)
BagHolder:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", 0, 0)


-- Show all bags
if show_all_bags then
	-- Set up holder frame
	BagHolder:SetWidth(160)

	-- Move bags
	MainMenuBarBackpackButton:ClearAllPoints()
	MainMenuBarBackpackButton:SetPoint("BOTTOMRIGHT", BagHolder, "BOTTOMRIGHT", -4, 4)
	MainMenuBarBackpackButton:SetScale(0.7)
	MainMenuBarBackpackButton:SetParent(BagHolder)
	KeyRingButton:SetParent(BagHolder)
	KeyRingButton:SetScale(0.7)

	for i=0,3 do
		_G["CharacterBag"..i.."Slot"]:SetParent(BagHolder)
		_G["CharacterBag"..i.."Slot"]:SetScale(0.8)
	end
end


-- Show only backpack
if not show_all_bags then
	-- Set up holder frame
	BagHolder:SetWidth(50)

	-- Move bags
	MainMenuBarBackpackButton:ClearAllPoints()
	MainMenuBarBackpackButton:SetPoint("BOTTOMRIGHT", BagHolder, "BOTTOMRIGHT", -4, 4)
	MainMenuBarBackpackButton:SetScale(0.7)
	MainMenuBarBackpackButton:SetParent(BagHolder)
	KeyRingButton:ClearAllPoints()
	KeyRingButton:SetPoint("BOTTOMLEFT", MainMenuBarBackpackButton, "BOTTOMLEFT", -22, -1)
	KeyRingButton:SetParent(BagHolder)
	KeyRingButton:SetScale(0.7)

	for i=0,3 do
		_G["CharacterBag"..i.."Slot"]:Hide()
	end

	-- Open all bags when clicking on the backpack
	MainMenuBarBackpackButton:SetScript("OnClick", function(self)
		OpenAllBags()
	end)
end


-- Scale bag container frames
for i=1,6 do
	_G["ContainerFrame"..i]:SetScale(0.9)
	_G["ContainerFrame"..i].SetScale = function() end
end




-- MICRO MENU -------------------------------------
-- Credit: Roth -----------------------------------

-- Holder frame
local fmicro = CreateFrame("Frame", "MicroMenuHolder", UIParent)
fmicro:SetWidth(155)
fmicro:SetHeight(25)
fmicro:SetPoint("BOTTOMLEFT", Minimap, "BOTTOMLEFT", -15, -42)

local MicroButtons = {
	CharacterMicroButton,
	SpellbookMicroButton,
	TalentMicroButton,
	AchievementMicroButton,
	QuestLogMicroButton,
	GuildMicroButton,
	PVPMicroButton,
	LFDMicroButton,
	MainMenuMicroButton,
	HelpMicroButton,
}


-- Move the micro menu
local function MoveMicroMenu()
	for _, f in pairs(MicroButtons) do
		f:SetParent(fmicro)
		f:SetScale(0.6)
	end
	CharacterMicroButton:ClearAllPoints()
	CharacterMicroButton:SetPoint("BOTTOMLEFT", 2, 2)
	GuildMicroButton:ClearAllPoints()
	GuildMicroButton:SetPoint("BOTTOMLEFT", QuestLogMicroButton, "BOTTOMRIGHT", -3, 0)
end


-- Hook into Blizzard functions to keep my frame position
hooksecurefunc("VehicleMenuBar_MoveMicroButtons", MoveMicroMenu)
MoveMicroMenu()




-- MINIMAP ----------------------------------------
---------------------------------------------------

MinimapCluster:ClearAllPoints()
MinimapCluster:SetPoint("TOPRIGHT", UIParent, "TOPRIGHT", -5, 5)
MinimapCluster:SetScale(0.9)
MiniMapWorldMapButton:Hide()
MinimapZoneTextButton:Hide()
MinimapBorderTop:Hide()
MinimapZoomOut:SetParent(MinimapZoomIn)	-- For mouseover script




-- WATCH FRAME (QUEST TRACKER) --------------------
---------------------------------------------------

-- Workaround to reposition the Watch Frame. Modify its anchor frame instead of moving the Watch frame itself.
-- Increase the height of the minimap, and reposition the contents back to their original position.
MinimapCluster:SetHeight(225)
MinimapBorder:ClearAllPoints()
MinimapBorder:SetPoint("TOP", 0, 18)
MinimapBorder:SetSize(192, 192)
MiniMapLFGFrame:ClearAllPoints()
MiniMapLFGFrame:SetPoint("TOPLEFT", 25, -90)
MinimapZoomIn:ClearAllPoints()
MinimapZoomIn:SetPoint("CENTER", 72, -13)
MinimapZoomOut:ClearAllPoints()
MinimapZoomOut:SetPoint("CENTER", -19, -19)
