
-- CONFIGURATION ----------------------------------


local unitframes_position = 0
-- 0. Top left position (SantaUI default)
-- 1. Bottom centered unitframes
-- 2. Blizzard default unitframes


local target_mana_number = true


-- END OF CONFIG ----------------------------------




local _, class = UnitClass("player")
local frame = CreateFrame("frame")


-- Move player frame
local function movePlayerFrame()
	if (unitframes_position == 0) then
		PlayerFrame:ClearAllPoints()
		PlayerFrame:SetPoint("TOPLEFT", -20, -7)
		PlayerFrame:SetScale(1.2)
		RuneFrame:SetScale(1.2)
	end
	
	if (unitframes_position == 1) then
		PlayerFrame:ClearAllPoints()
		PlayerFrame:SetPoint("BOTTOM", -220, 200)
		PlayerFrame:SetScale(1.1)
		RuneFrame:SetScale(1.1)
	end
end


-- Move rest of the frames
if (unitframes_position == 0) then
	TargetFrame:SetScale(1.2)
	TargetFrame:ClearAllPoints()
	TargetFrame:SetPoint("TOPLEFT", 220, -7)
	ComboFrame:SetScale(1.2)
	TargetFrameToT:SetScale(1)
	TargetFrameToT:ClearAllPoints()
	TargetFrameToT:SetPoint("RIGHT", TargetFrame, "RIGHT", 55, -7)
	PetFrame:SetScale(1.1)
	PetFrame:ClearAllPoints()
	if (class == "SHAMAN") then -- So pet frame wont collide with totems
		PetFrame:SetPoint("LEFT", PlayerFrame, "BOTTOM", -70, -20)
	else
		PetFrame:SetPoint("LEFT", PlayerFrame, "BOTTOM", -70, -15)
	end
end

if (unitframes_position == 1) then
	TargetFrame:SetScale(1.1)
	TargetFrame:ClearAllPoints()
	TargetFrame:SetPoint("BOTTOM", UIParent, "BOTTOM", 220, 200)
	ComboFrame:SetScale(1.1)
	TargetFrameSpellBar:ClearAllPoints()
	TargetFrameSpellBar:SetPoint("TOPLEFT", TargetFrame, "TOPLEFT", 4, 10)
	TargetFrameSpellBar.SetPoint = function() end
	TargetFrameToT:SetScale(1)
	TargetFrameToT:ClearAllPoints()
	TargetFrameToT:SetPoint("RIGHT", TargetFrame, "RIGHT", 54, -7)
	PetFrame:SetScale(1.0)
	PetFrame:ClearAllPoints()
	PetFrame:SetPoint("LEFT", PlayerFrame, "LEFT", -80, -10)
end


-- Hide pvp indicators
PlayerPVPIcon:SetAlpha(0)
TargetFrameTextureFramePVPIcon:SetAlpha(0)


-- Hide name background
--TargetFrameNameBackground:SetTexture(nil)


-- Party frames
for i=1,4 do
	_G["PartyMemberFrame"..i]:SetScale(1.3)
end




-- CLASS COLORED NAMES ----------------------------
---------------------------------------------------

-- Player
local function playerNameColor(player, ...)
	local _, playerClass = UnitClass("player")
	local playerColor = RAID_CLASS_COLORS[playerClass]
	PlayerName:SetTextColor(playerColor.r, playerColor.g, playerColor.b)
end


-- Target
local function targetNameColor(target, ...)
	local isPlayer = UnitIsPlayer("target")
	local _, targetClass = UnitClass("target")
	local targetClassColor = RAID_CLASS_COLORS[targetClass]
	if (isPlayer == 1) and not (targetClassColor == nil) then
		TargetFrameTextureFrameName:SetTextColor(targetClassColor.r, targetClassColor.g, targetClassColor.b) else
		TargetFrameTextureFrameName:SetTextColor(1, 0.8, 0)
	end
	TargetFrameNameBackground:SetAlpha(0.2)
end


-- Target of target
local function totNameColor(targettarget)
	local totTargetIsPlayer = UnitIsPlayer("targettarget")
	local _, totTargetClass = UnitClass("targettarget")
	local totTargetClassColor = RAID_CLASS_COLORS[totTargetClass]
	if (totTargetIsPlayer == 1) and not (totTargetClassColor == nil) then
		TargetFrameToTTextureFrameName:SetTextColor(totTargetClassColor.r, totTargetClassColor.g, totTargetClassColor.b) else
		TargetFrameToTTextureFrameName:SetTextColor(1, 0.8, 0)
	end
end


-- Focus
local function focusNameColor(...)
	local focusIsPlayer = UnitIsPlayer("focus")
	local _, focusClass = UnitClass("focus")
	local focusClassColor = RAID_CLASS_COLORS[focusClass]
	if (focusIsPlayer == 1) and not (focusClassColor == nil) then
		FocusFrameTextureFrameName:SetTextColor(focusClassColor.r, focusClassColor.g, focusClassColor.b) else
		FocusFrameTextureFrameName:SetTextColor(1, 0.8, 0)
	end
end




-- ALWAYS SHOW MANA AS A # ------------------------
---------------------------------------------------

local function fixManaText(target, ...)
	if target_mana_number then
		TargetFrameManaBar.TextString:SetText(TextStatusBar_CapDisplayOfNumericValue(UnitMana("target")))
	end
end




-- EVENTS -----------------------------------------
---------------------------------------------------

frame:RegisterEvent("PLAYER_ENTERING_WORLD")
frame:RegisterEvent("PLAYER_TARGET_CHANGED")
frame:RegisterEvent("PLAYER_REGEN_ENABLED")
frame:RegisterEvent("PLAYER_FOCUS_CHANGED")
frame:RegisterEvent("UNIT_TARGET")
frame:RegisterEvent("UNIT_POWER")

frame:SetScript("OnEvent", function(self, event, arg1)

	if (event == "PLAYER_ENTERING_WORLD") then
		movePlayerFrame()
		playerNameColor()
	end


	if (event == "PLAYER_TARGET_CHANGED") then
		targetNameColor()
		fixManaText()
	end


	if (event == "PLAYER_REGEN_ENABLED") then
		frame:UnregisterEvent("PLAYER_REGEN_ENABLED")
		movePlayerFrame()
		PlayerFrame:SetAlpha(1)
	end


	if (event == "PLAYER_FOCUS_CHANGED") then
		focusNameColor()
	end


	if (event == "UNIT_TARGET") then
		totNameColor()
	end


	if (event == "UNIT_POWER") then
		fixManaText()
	end
end)


-- Hooks to make sure player frame get back to their position when entering/leaving a vehicle
hooksecurefunc("PlayerFrame_AnimateOut", function()
	if not (UnitAffectingCombat("player")) then
		PlayerFrame:SetAlpha(0)
		movePlayerFrame()
	else
		frame:RegisterEvent("PLAYER_REGEN_ENABLED")
	end
end)

hooksecurefunc("PlayerFrame_SequenceFinished", function()
	if not (UnitAffectingCombat("player")) then
		PlayerFrame:SetAlpha(1)
		movePlayerFrame()
	else
		frame:RegisterEvent("PLAYER_REGEN_ENABLED")
	end
end)
